<?php

/**
 * Enqueue the parent theme stylesheet.
 */
add_action( 'wp_enqueue_scripts', 'vantage_parent_style' );
function vantage_parent_style() {
    wp_enqueue_style( 'parent-theme', get_template_directory_uri() . '/style.css' );
}

/**
 * Enqueue the child theme stylesheet.
 */
add_action( 'wp_enqueue_scripts', 'vantage_child_style', 20 );
function vantage_child_style() {
    wp_enqueue_style( 'child-theme', get_stylesheet_uri() );
}

/**
 * Set the child theme text domain.
 */
function vantage_child_set_text_domain(){
	load_theme_textdomain( 'vantage', get_stylesheet_directory() . '/languages' );
}
add_action('after_setup_theme', 'vantage_child_set_text_domain', 15);

/**
 * Add the field to the checkout
 */
add_action('woocommerce_after_order_notes', 'my_custom_checkout_field');
function my_custom_checkout_field( $checkout ) {
	echo '<div id="my_custom_checkout_field"><span>'.__('Personnummer obligatoriskt för fakturering,').'</span>';
	woocommerce_form_field( 'my_field_name', array(
	'type'          => 'text',
	'class'         => array('my-field-class form-row-wide'),
	'label'         => __('10 siffror ÅÅMMDD-NNNN'),
	'placeholder'       => __('Ditt personnummer, 10 siffror ÅÅMMDD-NNNN'),
	'required'   => false,
	), $checkout->get_value( 'my_field_name' ));
	echo '</div>';
}

/**
 * Process the checkout
 */
add_action('woocommerce_checkout_process', 'my_custom_checkout_field_process');
function my_custom_checkout_field_process() {
	global $woocommerce;
	// Check if set, if its not set add an error.
	if (!$_POST['my_field_name'])
	$woocommerce->add_error( __('Please enter something into this new shiny field.') );
}

/**
 * Update the order meta with field value
 */
add_action('woocommerce_checkout_update_order_meta', 'my_custom_checkout_field_update_order_meta');
function my_custom_checkout_field_update_order_meta( $order_id ) {
	if ($_POST['my_field_name']) update_post_meta( $order_id, 'My Field', esc_attr($_POST['my_field_name']));
}

/**
 * Enqueue scripts and styles.
 */
add_filter('woocommerce_email_order_meta_keys', 'my_custom_checkout_field_order_meta_keys');
function my_custom_checkout_field_order_meta_keys( $keys ) {
	$keys[] = 'My Field';return $keys;
}